@@ -2,7 +2,7 @@ package FBP::Project;
 
 use Mouse;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 extends 'FBP::Object';
 with    'FBP::Children';
@@ -12,6 +12,15 @@ has internationalize => (
 	isa => 'Bool',
 );
 
+no Mouse;
+
+
+
+
+
+######################################################################
+# Convenience Methods
+
 sub dialogs {
 	return grep { 
 		Params::Util::_INSTANCE($_, 'FBP::Dialog')
