@@ -11,7 +11,7 @@ FBP::Window - Base class for all graphical wxWindow objects
 use Mouse;
 use Scalar::Util ();
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 extends 'FBP::Object';
 with    'FBP::Children';
@@ -67,6 +67,20 @@ has enabled => (
 
 =pod
 
+=head2 hidden
+
+The C<hidden> method indicates if the object is true if the shown is removed
+from view, or false if the window is shown.
+
+=cut
+
+has hidden => (
+	is  => 'ro',
+	isa => 'Bool',
+);
+
+=pod
+
 =head2 subclass
 
 The C<subclass> method returns the literal C-style 'subclass' property
